California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 048 - REFERENDUM TO OVERTURN INDIAN GAMING COMPACTS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1359411 | YES ON PROP. 48. VOTERS FOR CENTRAL VALLEY JOBS & ENVIRONMENT A COALITION TRIBES, LABOR ORGS, BUSNS & ENVIRON. GRPS, SPON. & MJR FUNDING NORTH FORK RANCHERIA OF MONO INDIANS & STATION CASINOS LLC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372891 | FIRST AMERICANS FOR KEEPING THE PROMISE, NO ON 48, A COALITION OF CALIFORNIA INDIAN GAMING TRIBES, SPONSORED AND MAJOR FUNDING BY PECHANGA BAND OF LUISENO INDIANS & MAJOR FUNDING BY TABLE MOUNTAIN ... | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1359207 | NO ON PROP. 48 - KEEP VEGAS-STYLE CASINOS OUT OF NEIGHBORHOODS, A PROJECT OF STAND UP FOR CALIFORNIA | OPPOSE